@@ -1,3 +1,6 @@
+#![allow(incomplete_features)]
+#![feature(specialization)]
+
 pub mod streams;
 pub mod serialize;
 pub mod primitives;
